@@ -17,6 +17,7 @@
 from octobot_commons.display import display_translator
 from octobot_commons.display.display_translator import (
     DisplayTranslator,
+    Element,
 )
 
 from octobot_commons.display import display_factory
@@ -24,5 +25,10 @@ from octobot_commons.display.display_factory import (
     display_translator_factory,
 )
 
+from octobot_commons.display import plot_settings
+from octobot_commons.display.plot_settings import (
+    PlotSettings,
+)
 
-__all__ = ["DisplayTranslator", "display_translator_factory"]
+
+__all__ = ["DisplayTranslator", "Element", "display_translator_factory", "PlotSettings"]
